Name:          qoauth
Summary:       Qt-based C++ library for OAuth authorization scheme
Group:         Graphical desktop/KDE
Version:       2.0.1
Release:       %mkrel 10
License:       LGPLv2+
URL:           http://github.com/ayoy/qoauth
# tarball 2.0.1 come from: https://github.com/ayoy/qoauth/commit/02fbc13a42d945b703a28a49d71c02b20c76a0b8
Source0:       http://files.ayoy.net/qoauth/release/%{version}/src/%{name}-%{version}-src.tar.gz
Patch100:      qoauth-2.0.0-qt5.patch
BuildRequires: doxygen

BuildRequires: pkgconfig(Qt5Core)
BuildRequires: pkgconfig(Qt5Network)
BuildRequires: pkgconfig(Qt5Test)
BuildRequires: pkgconfig(qca2-qt5)

%description
QOAuth is an attempt to support interaction with OAuth-powered network
services in a Qt way, i.e. simply, clearly and efficiently. It gives
the application developer no more than 4 methods, namely:

* requestToken() to obtain an unauthorized Request Token,
* accessToken() to exchange Request Token for the Access Token,
* createParametersString() to construct a request according to OAuth
  authorization scheme,
* inlineParemeters() - to construct a query string basing on given
  parameters (provided only for convenience).

#-----------------------------------------------------------------------------
### Qt5 ###

%define qoauth_qt5_major 2
%define libqoauth_qt5 %mklibname qoauth-qt 5 %{qoauth_qt5_major}

%package -n    %{libqoauth_qt5}
Summary:       %{name} Qt5 core library
Group:         System/Libraries
Requires:      qca-qt5
Obsoletes:     %{_lib}qoauth5_2 < 2.0.1-3

%description -n %{libqoauth_qt5}
%{name} Qt5 core library.

%files -n %{libqoauth_qt5}
%{_qt5_libdir}/libqoauth-qt5.so.%{qoauth_qt5_major}{,.*}

#-----------------------------------------------------------------------------

%define develname_qt5 %mklibname qoauth-qt5 -d

%package -n    %{develname_qt5}
Summary:       Qt5 Devel stuff for %{name}
Group:         Development/KDE and Qt
Requires:      %{libqoauth_qt5} = %{version}-%{release}
Provides:      qoauth-qt5-devel = %{version}-%{release}
Provides:      libqoauth-qt5-devel = %{version}-%{release}

%description -n %{develname_qt5}
This package contains Qt5 header files needed if you wish to build
applications based on %{name}.

%files -n %{develname_qt5}
%{_qt5_includedir}/QtOAuth/
#{_qt5_libdir}/libqoauth5.prl
%{_qt5_libdir}/libqoauth-qt5.so
%{_qt5_libdir}/pkgconfig/qoauth-qt5.pc
%{_qt5_archdatadir}/mkspecs/features/oauth.prf

### End Qt5 ###
#-----------------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}-src

%autopatch -p1

%build
mkdir %{_target_platform}-qt5
pushd %{_target_platform}-qt5
export PATH=%{_qt5_bindir}:$PATH
%{qmake_qt5} PREFIX="%{_prefix}" ..
%make_build
popd

%if 0%{?docs}
doxygen Doxyfile
# fix the time stamp
for file in doc/html/*; do
  touch -r Doxyfile $file
done
%endif


%install
make install INSTALL="install -p" INSTALL_ROOT=%{buildroot} -C %{_target_platform}-qt5

## FIXME
sed -i \
  -e "s|^includedir=.*|includedir=%{_qt5_includedir}/QtOAuth|" \
  -e "s|^libdir=.*|libdir=%{_qt5_libdir}|" \
  %{buildroot}%{_qt5_libdir}/pkgconfig/qoauth-qt5.pc

## unpackaged files
rm -f %{buildroot}%{_qt5_libdir}/libqoauth-qt5.prl


%check
make check -C %{_target_platform}-qt5 || :


%changelog
* Thu Dec 17 2020 umeabot <umeabot> 2.0.1-10.mga8
+ Revision: 1659544
- Rebuild for new Qt5

* Wed Nov 11 2020 joequant <joequant> 2.0.1-9.mga8
+ Revision: 1644590
- build with new qca-qt5

* Tue Feb 18 2020 umeabot <umeabot> 2.0.1-8.mga8
+ Revision: 1541117
- Mageia 8 Mass Rebuild

* Fri Dec 20 2019 daviddavid <daviddavid> 2.0.1-7.mga8
+ Revision: 1469120
- time to drop Qt4 support

* Thu Dec 19 2019 daviddavid <daviddavid> 2.0.1-6.mga8
+ Revision: 1468998
- rebuild against new botan2/qca-qt5

* Fri Jul 26 2019 daviddavid <daviddavid> 2.0.1-5.mga8
+ Revision: 1424448
- rebuild for new Qt5 headers path and new mkspecs macros

* Mon Apr 01 2019 umeabot <umeabot> 2.0.1-4.mga7
+ Revision: 1384247
- Qt5 Rebuild

* Sat Sep 08 2018 wally <wally> 2.0.1-3.mga7
+ Revision: 1257784
- sync Qt5 patch and partially .spec with Fedora
  - update qt5 libname

* Wed Jun 15 2016 daviddavid <daviddavid> 2.0.1-2.mga6
+ Revision: 1021511
- fix QtOAuth includedir path in oauth.prf file from Qt5 (fixes mga#18711)

* Sun May 22 2016 daviddavid <daviddavid> 2.0.1-1.mga6
+ Revision: 1017468
- new version: 2.0.1
- add Qt5 support (needed now for choqok port to KF5)

* Wed Feb 03 2016 umeabot <umeabot> 1.0.1-9.mga6
+ Revision: 933605
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.0.1-8.mga5
+ Revision: 739417
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.1-7.mga5
+ Revision: 688501
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.0.1-6.mga4
+ Revision: 517872
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.0.1-5.mga3
+ Revision: 379862
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jun 27 2011 ahmad <ahmad> 1.0.1-4.mga2
+ Revision: 114927
- libify the devel package (and add some more provides)
- Correct the License tag
- Move the doxygen building to %%build

* Wed Feb 16 2011 mikala <mikala> 1.0.1-3.mga1
+ Revision: 52105
- Remove BuildRoot
- imported package qoauth


* Fri Jan 28 2011 Sergio Rafael Lemke <sergio@mandriva.com> 1.0.1-3mdv2011.0
+ Revision: 633706
- bump release to make choqok and other buildable

* Fri Aug 20 2010 Funda Wang <fwang@mandriva.org> 1.0.1-2mdv2011.0
+ Revision: 571482
- move requires into lib package as there is no main package generated.
- correct url and license
- use standard prefix as qt has nothing to do with kde's prefix

* Sat Aug 14 2010 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.1-1mdv2011.0
+ Revision: 569811
- Fix file list
- import qoauth


